aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/graph/nodes/FullyConnectedLayerNode.h
diff options
context:
space:
mode:
authorGeorgios Pinitas <georgios.pinitas@arm.com>2018-04-27 19:07:19 +0100
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:51:17 +0000
commitcac13b1cfd593889271f8e2191be2039b8d88f36 (patch)
treed1c5196877d7fbd5dcfbb9f9003faf6035f82a33 /arm_compute/graph/nodes/FullyConnectedLayerNode.h
parentad0c7388f6261989a268ffb2d042f2bd80736e3f (diff)
downloadComputeLibrary-cac13b1cfd593889271f8e2191be2039b8d88f36.tar.gz
COMPMID-1097: Port mobilenet to NHWC
Change-Id: I789065bfa0d4ef133388e1904c5caf31e450f80f Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/129495 Tested-by: Jenkins <bsgcomp@arm.com> Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Diffstat (limited to 'arm_compute/graph/nodes/FullyConnectedLayerNode.h')
-rw-r--r--arm_compute/graph/nodes/FullyConnectedLayerNode.h21
1 files changed, 10 insertions, 11 deletions
diff --git a/arm_compute/graph/nodes/FullyConnectedLayerNode.h b/arm_compute/graph/nodes/FullyConnectedLayerNode.h
index 166751b8fa..3d1b68909a 100644
--- a/arm_compute/graph/nodes/FullyConnectedLayerNode.h
+++ b/arm_compute/graph/nodes/FullyConnectedLayerNode.h
@@ -39,29 +39,28 @@ public:
* @param[in] num_outputs Number of neurons in the layer
*/
FullyConnectedLayerNode(unsigned int num_outputs);
/** Computes weights shape
*
* @warning Works for inputs with 1D batch space
*
* @param[in] input_shape Input shape
* @param[in] num_outputs Number of output neurons
*
- * @return Weights shape
+ * @return Weights descriptor
*/
- static TensorShape compute_weights_shape(TensorShape input_shape, unsigned int num_outputs);
- /** Computes fully connected layer output shape
+ static TensorDescriptor compute_weights_descriptor(const TensorDescriptor &input_descriptor, unsigned int num_outputs);
+ /** Computes fully connected layer output descriptor
*
* @warning Works for inputs with 1D batch space
*
* @param[in] input_shape Input shape
* @param[in] num_outputs Number of output neurons
*
- * @return Output shape
+ * @return Output descriptor
*/
- static TensorShape compute_output_shape(TensorShape input_shape, unsigned int num_outputs);
+ static TensorDescriptor compute_output_descriptor(const TensorDescriptor &input_descriptor, unsigned int num_outputs);
// Inherited overridden methods:
- Status validate() override;
NodeType type() const override;
bool forward_descriptors() override;
TensorDescriptor configure_output(size_t idx) const override;
@@ -39,29 +39,28 @@ public:
*/
FullyConnectedLayerNode(unsigned int num_outputs);
- /** Computes weights shape
+ /** Computes weights descriptor
*
* @warning Works for inputs with 1D batch space
@@ -39,29 +39,28 @@ public:
* @warning Works for inputs with 1D batch space
*
- * @param[in] input_shape Input shape
- * @param[in] num_outputs Number of output neurons
+ * @param[in] input_descriptor Input descriptor
+ * @param[in] num_outputs Number of output neurons
*
@@ -39,29 +39,28 @@ public:
* @warning Works for inputs with 1D batch space
*
- * @param[in] input_shape Input shape
- * @param[in] num_outputs Number of output neurons
+ * @param[in] input_descriptor Input descriptor
+ * @param[in] num_outputs Number of output neurons
*